import { Resource, Timestamp } from '3a-common';
import { ElementNote } from '../notifications';
/**
 * Element interface
 */
export interface Element extends Resource {
    /**
     * Organization nit that the element belongs to
     */
    organization: string;
    /**
     * Tag associated to the element
     */
    tag?: string;
    /**
     * Element description
     */
    description?: string;
    /**
     * Zone Id that the element belongs to
     */
    zoneId?: string;
    /**
     * Element Image URL/URI
     */
    imageUrl?: string;
    /**
     * Element historic events ids
     */
    historicEventsIds: string[];
    /**
     * Element notes
     */
    notes: ElementNote[];
    /**
     * Element type
     */
    elementType: ElementType;
    /**
     * Element status
     */
    status: string;
    /**
     * Element status
     */
    zoneName: string;
    /**
     * Element extra propeties
     */
    [_: string]: any;
}
/**
 * Historic event of element interface
 */
export interface ElementHistoricEvent extends Resource {
    /**
     * Related element id
     */
    tagID: string;
    /**
     * Related zone id
     */
    zoneID: string;
    /**
     * Related zone id
     */
    zoneName: string;
    /**
     * Related direction event
     */
    direction?: RFIDEventDirection;
    /**
     * Time when the event was created
     */
    date: Timestamp;
    /**
     * Event description
     */
    description?: string;
    /**
     * Historic event author id
     */
    author?: string;
    /**
     *  element key in table
     */
    id?: string;
    /**
     * resorce id associated
     */
    resourceID?: string;
}
/**
 * Event direction interface
 */
export declare enum RFIDEventDirection {
    ENTER = 0,
    EXIT = 1
}
/**
 * Anotation event of element interface
 */
export interface ElementAnotationEvent extends Resource {
    /**
     * Related element id
     */
    elementID: string;
    /**
     * Time when the event was created
     */
    date: Timestamp;
    /**
     * Event description
     */
    description?: string;
    /**
     * Historic event author id
     */
    author?: string;
}
/**
 * Zone interface
 */
export interface Zone extends Resource {
    /**
     * RFID readers Ids in the zone
     */
    rfIdReadersIds: string[];
    /**
     * Zone description
     */
    description?: string;
}
/**
 * RFID reader interface
 */
export interface RFIDReader extends Resource {
    /**
     * Zone where RFID reader is located
     */
    zone: Zone;
}
/**
 * RFID Reading interface
 */
export interface RFIDReading extends Resource {
    /**
     * RFID reader id that made the reading
     */
    rfIdReader: RFIDReader;
    /**
     * Read tag
     */
    tag: string;
    /**
     * Timestamp when reading was made
     */
    date: Timestamp;
}
/**
 * Element type interface
 */
export interface ElementType extends Resource {
}
